@@ -65,6 +65,28 @@ class BaseMongoDB(object):
     def update_one(self, key: dict, obj: dict):
         return self.task.update_one(key, {"$set": obj}, upsert=True).raw_result
 
+    def push_one(self, key: dict, where: str, obj: dict):
+        """
+        向array插入一条数据
+        e.g. mongodb_cursor.push_one({'id': 0}, 'standby', {'task_id': 'mongopushtest', 'number': 'heyhey'})
+        """
+        return self.task.update_one(key, {"$push": {where: obj}}, upsert=True).raw_result
+
+    def pull_one(self, key: dict, obj: dict):
+        """
+        从array删除一条数据
+        e.g. mongodb_cursor.pull_one({'id': 0}, {'standby': {'task_id': 'mongopushtest'}})
+        """
+        return self.task.update_one(key, {"$pull": obj}, upsert=True).raw_result
+
+    def pop_one(self, key: dict, where: str):
+        """
+        从array弹出最早的一条数据
+        注意目前where只支持一级目录，不支持比较复杂位置的array（后期再优化吧
+        """
+        res = self.task.find_one_and_update(key, {"$pop": {where: -1}}, upsert=True)
+        return res[where][0] if res[where] else []
+
     def increment_one(self, key: dict, obj_key: str, step: int):
         """
         对表里的某个数进行自增、自减操作
